@@ -131,6 +131,7 @@ class RSAKey (PKey):
     def write_private_key(self, file_obj, password=None):
         self._write_private_key('RSA', file_obj, self._encode_key(), password)
 
+    @staticmethod
     def generate(bits, progress_func=None):
         """
         Generate a new private RSA key.  This factory function can be used to
@@ -148,7 +149,6 @@ class RSAKey (PKey):
         key.p = rsa.p
         key.q = rsa.q
         return key
-    generate = staticmethod(generate)
 
     ###  internals...
 
