@@ -610,7 +610,7 @@ class SFTPTest (unittest.TestCase):
 
         with sftp.open(FOLDER + '/bunny.txt', 'rb') as f:
             self.assertEqual(text, f.read(128))
-        self.assertEqual([(41, 41)], saved_progress)
+        self.assertEqual((41, 41), saved_progress[-1])
 
         os.unlink(localname)
         fd, localname = mkstemp()
@@ -620,7 +620,7 @@ class SFTPTest (unittest.TestCase):
 
         with open(localname, 'rb') as f:
             self.assertEqual(text, f.read(128))
-        self.assertEqual([(41, 41)], saved_progress)
+        self.assertEqual((41, 41), saved_progress[-1])
 
         os.unlink(localname)
         sftp.unlink(FOLDER + '/bunny.txt')
@@ -696,7 +696,8 @@ class SFTPTest (unittest.TestCase):
                 f.readv([(0, 12)])
 
             with sftp.open(FOLDER + '/zero', 'r') as f:
-                f.prefetch()
+                file_size = f.stat().st_size
+                f.prefetch(file_size)
                 f.read(100)
         finally:
             sftp.unlink(FOLDER + '/zero')
