@@ -57,14 +57,12 @@ class NullServer (paramiko.ServerInterface):
 
 
 class GSSAuthTest(unittest.TestCase):
-
+    @staticmethod
     def init(username, hostname):
         global krb5_principal, targ_name
         krb5_principal = username
         targ_name = hostname
 
-    init = staticmethod(init)
-
     def setUp(self):
         self.username = krb5_principal
         self.hostname = socket.getfqdn(targ_name)
@@ -104,7 +102,7 @@ class GSSAuthTest(unittest.TestCase):
                         gss_auth=True)
 
         self.event.wait(1.0)
-        self.assert_(self.event.isSet())
+        self.assert_(self.event.is_set())
         self.assert_(self.ts.is_active())
         self.assertEquals(self.username, self.ts.get_username())
         self.assertEquals(True, self.ts.is_authenticated())
